<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl" sourcelanguage="en_US">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/application.cpp" line="427"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="104"/>
        <location filename="../src/application.cpp" line="150"/>
        <source>Draw</source>
        <translation>Draw</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="426"/>
        <source>You can import up to 30 pictures, please try again!</source>
        <translation>Możesz zaimportować do 30 zdjęć, spróbuj ponownie!</translation>
    </message>
</context>
<context>
    <name>BlurWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="100"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="110"/>
        <source>Blur</source>
        <translation>Rozmazać</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="123"/>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="146"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
</context>
<context>
    <name>CAbstractProcessDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cprogressdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>CAlphaControlWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/calphacontrolwidget.cpp" line="65"/>
        <source>Alpha</source>
        <translation>Alfa</translation>
    </message>
</context>
<context>
    <name>CCutDialog</name>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="41"/>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="42"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="47"/>
        <source>Do you want to save the cropped image?</source>
        <translation>Czy chcesz zachować wykadrowany obraz?</translation>
    </message>
</context>
<context>
    <name>CCutTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ccuttool.cpp" line="90"/>
        <source>Crop (C)</source>
        <translation>Wykadruj (C)</translation>
    </message>
</context>
<context>
    <name>CCutWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="230"/>
        <source>Dimensions</source>
        <translation>Wymiary</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="245"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="295"/>
        <source>Aspect ratio</source>
        <translation>Współczynnik kształtu</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="336"/>
        <source>Free</source>
        <translation>Wolny</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="343"/>
        <source>Original</source>
        <translation>Oryginalny</translation>
    </message>
</context>
<context>
    <name>CEllipseTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cellipsetool.cpp" line="57"/>
        <source>Ellipse (O)</source>
        <translation>Elipsa (O)</translation>
    </message>
</context>
<context>
    <name>CEraserTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="98"/>
        <source>Eraser (E)</source>
        <translation>Gumka (E)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="113"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="548"/>
        <source>Percentage</source>
        <translation>Procent</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="562"/>
        <source>Pixels</source>
        <translation>Pikseli</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="564"/>
        <source>Dimensions:</source>
        <translation>Wymiary:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="586"/>
        <source>Lock aspect ratio</source>
        <translation>Zablokuj proporcje obrazu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="595"/>
        <source>W:</source>
        <translation>S:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="600"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="611"/>
        <source>pixels</source>
        <translation>pikseli</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="605"/>
        <source>H:</source>
        <translation>W:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="868"/>
        <source>It supports up to 10,000 pixels</source>
        <translation>Wspiera do 10,000 pikseli</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="98"/>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="173"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="186"/>
        <source>Pictures</source>
        <translation>Zdjęcia</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="188"/>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="189"/>
        <source>Downloads</source>
        <translation>Pliki do pobrania</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="190"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="191"/>
        <source>Videos</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="192"/>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="193"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="207"/>
        <source>Select other directories</source>
        <translation>Wybierz inne katalogi</translation>
    </message>
    <message>
        <source>jpg</source>
        <translation type="vanished">jpg</translation>
    </message>
    <message>
        <source>png</source>
        <translation type="vanished">png</translation>
    </message>
    <message>
        <source>bmp</source>
        <translation type="vanished">bmp</translation>
    </message>
    <message>
        <source>tif</source>
        <translation type="vanished">tif</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="265"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="266"/>
        <source>Save to:</source>
        <translation>Zapisz do:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="268"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="269"/>
        <source>Quality:</source>
        <translation>Jakość:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="275"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="281"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="276"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="282"/>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="406"/>
        <source>This file will be hidden if the file name starts with a dot (.). Do you want to hide it?</source>
        <translation>Ten plik zostanie ukryty jeśli jego nazwa zaczyna się kropką. Czy chcesz go ukryć?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="421"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="423"/>
        <source>The file name is too long</source>
        <translation>Nazwa pliku jest zbyt długa</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="506"/>
        <source>%1 
 already exists, do you want to replace it?</source>
        <translation>%1 
już istnieje, czy chcesz go wymienić?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="866"/>
        <source>At least one pixel please</source>
        <translation>Co najmniej jeden piksel proszę</translation>
    </message>
</context>
<context>
    <name>CLineTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/clinetool.cpp" line="58"/>
        <source>Line (L)</source>
        <translation>Linia (L)</translation>
    </message>
</context>
<context>
    <name>CPenTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="79"/>
        <source>Pencil (P)</source>
        <translation>Ołówek (P)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="96"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="124"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="167"/>
        <source>Watercolor</source>
        <translation>Plakatówki</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="168"/>
        <source>Calligraphy pen</source>
        <translation>Długopis kaligraficzny</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="169"/>
        <source>Crayon</source>
        <translation>Kredka</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="514"/>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
</context>
<context>
    <name>CPictureTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="87"/>
        <source>Import (I)</source>
        <translation>Import (I)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="114"/>
        <source>Rotate 90° CCW</source>
        <translation>Obróć o 90° w lewo</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="132"/>
        <source>Rotate 90° CW</source>
        <translation>Obróć o 90° w prawo</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="149"/>
        <source>Flip horizontally</source>
        <translation>Obróć poziomo</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="169"/>
        <source>Flip vertically</source>
        <translation>Odwróć w pionie</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="188"/>
        <source>Auto fit</source>
        <translation>Auto dopasowywanie</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="232"/>
        <source>Import Picture</source>
        <translation>Importuj obraz</translation>
    </message>
</context>
<context>
    <name>CPolygonTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="69"/>
        <source>Polygon (H)</source>
        <translation>Wielokąt (H)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="86"/>
        <source>Sides</source>
        <translation>Strony</translation>
    </message>
</context>
<context>
    <name>CPolygonalStarTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="49"/>
        <source>Star (F)</source>
        <translation>Gwiazda (F)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="90"/>
        <source>Points</source>
        <translation>Punkty</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="97"/>
        <source>Radius</source>
        <translation>Promień</translation>
    </message>
</context>
<context>
    <name>CRectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="68"/>
        <source>Rectangle (R)</source>
        <translation>Prostokąt (R)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="136"/>
        <source>Fill</source>
        <translation>Wypełnij</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="142"/>
        <source>Corner Radius</source>
        <translation>Promień kątowy</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="273"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
</context>
<context>
    <name>CSelectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="90"/>
        <source>Select (V)</source>
        <translation>Wybierz (V)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="124"/>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
</context>
<context>
    <name>CTextTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="68"/>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="99"/>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="229"/>
        <source>Input text here</source>
        <translation>Wpisz tekst tutaj</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="328"/>
        <source>Weight</source>
        <translation>Waga</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="344"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="469"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
</context>
<context>
    <name>CTriangleTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctriangletool.cpp" line="62"/>
        <source>Triangle (S)</source>
        <translation>Trójkąt (S)</translation>
    </message>
</context>
<context>
    <name>ColorPanel</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/colorpanel.cpp" line="175"/>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
</context>
<context>
    <name>DrawAttribution::CGroupButtonWgt</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="487"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="499"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="490"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="507"/>
        <source>Ungroup</source>
        <translation>Odznacz grupowanie</translation>
    </message>
</context>
<context>
    <name>DrawDialog</name>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="43"/>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="44"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="47"/>
        <source>Save the current contents?</source>
        <translation>Zapisać bieżącą zawartość?</translation>
    </message>
</context>
<context>
    <name>FileHander</name>
    <message>
        <location filename="../src/service/filehander.cpp" line="596"/>
        <source>Opening...</source>
        <translation>Otwieranie...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="623"/>
        <source>Saving...</source>
        <translation>Zapisywanie...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="650"/>
        <source>Damaged file, unable to open it</source>
        <translation>Uszkodzony plik, nie można go otworzyć</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="705"/>
        <location filename="../src/service/filehander.cpp" line="828"/>
        <source>The file does not exist</source>
        <translation>Plik nie istnieje</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="724"/>
        <source>Unable to open &quot;%1&quot;, unsupported file format</source>
        <translation>Nie można otworzyć &quot;%1&quot;, nieobsługiwany format pliku</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="749"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Nazwa pliku nie może zawierać \/:*?&quot;&lt;&gt;|</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="839"/>
        <source>Unable to open the write-only file &quot;%1&quot;</source>
        <translation>Nie można otworzyć pliku tylko do zapisu &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="852"/>
        <source>This file is read-only, please save with another name</source>
        <translation>Ten plik jest tylko do odczytu, zapisz go innym razem</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="860"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nie posiadasz wystarczających uprawnień, aby zapisywać tutaj pliki</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="881"/>
        <source>The file is incompatible with the old app, please install the latest version</source>
        <translation>Ten plik jest niekompatybilny ze starą aplikacją, zainstaluj najnowszą wersję</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="899"/>
        <source>Unable to open the broken file &quot;%1&quot;</source>
        <translation>Nie można otworzyć zepsutego pliku &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>FileSelectDialog</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="202"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Nazwa pliku nie może zawierać \/:*?&quot;&lt;&gt;|</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="204"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="231"/>
        <source>Cannot save it as %1, since the file in that name is open now.
Please save it in another name or close that file and try again.</source>
        <translation>Nie można zapisać jako %1 ponieważ taki plik jest już otwarty.
Zapisz go pod inną nazwą alby zamknij otwarty już plik i spróbuj ponownie.</translation>
    </message>
</context>
<context>
    <name>IBlurTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cmasicotool.cpp" line="148"/>
        <source>Blur (B)</source>
        <translation>Rozmarz (B)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="105"/>
        <source>Draw</source>
        <translation>Draw</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export successful</source>
        <translation>Eksport zakończony powodzeniem</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export failed</source>
        <translation>Eksport zakończony niepowodzeniem</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="228"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
</context>
<context>
    <name>PageContext</name>
    <message>
        <location filename="../src/drawshape/cdrawparamsigleton.cpp" line="66"/>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
</context>
<context>
    <name>PageView</name>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="322"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="666"/>
        <source>Layer</source>
        <translation>Warstwa</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="324"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="683"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="329"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="684"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="334"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="685"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="341"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="686"/>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="348"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="692"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="354"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="687"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="363"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="688"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="372"/>
        <source>Raise Layer</source>
        <translation>Podnieś warstwę</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="377"/>
        <source>Lower Layer</source>
        <translation>Niższa warstwa</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="382"/>
        <source>Layer to Top</source>
        <translation>Warstwa do góry</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="387"/>
        <source>Layer to Bottom</source>
        <translation>Warstwa do dołu</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="416"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="421"/>
        <source>Ungroup</source>
        <translation>Odznacz grupowanie</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="427"/>
        <source>Align</source>
        <translation>Wyrównaj</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="430"/>
        <source>Align left</source>
        <translation>Wyrównaj do lewej</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="435"/>
        <source>Horizontal centers</source>
        <translation>Horyzontalne środki</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="440"/>
        <source>Align right</source>
        <translation>Wyrównaj do prawej</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="445"/>
        <source>Align top</source>
        <translation>Wyrównaj do góry</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="450"/>
        <source>Vertical centers</source>
        <translation>Pionowe środki</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="455"/>
        <source>Align bottom</source>
        <translation>Wyrównaj do dołu</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="460"/>
        <source>Distribute horizontal space</source>
        <translation>Rozprowadź miejsce w poziomie</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="462"/>
        <source>Distribute vertical space</source>
        <translation>Rozprowadź miejsce w pionie</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="689"/>
        <source>Text Align Left</source>
        <translation>Tekst wyrównaj do lewej</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="690"/>
        <source>Text Align Right</source>
        <translation>Tekst wyrównaj do prawej</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="691"/>
        <source>Text Align Center</source>
        <translation>Wyśrodkuj tekst</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="75"/>
        <location filename="../src/frame/cviewmanagement.cpp" line="202"/>
        <source>File not saved</source>
        <translation>Plik nie zapisany</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="355"/>
        <source>Source Han Sans CN</source>
        <translation>Źródło Han Sans CN</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="84"/>
        <source>Stroke</source>
        <translation>Wygładź</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="103"/>
        <source>The blur effect will be lost as the file is in old version. Proceed to open it?</source>
        <translation>Efekt rozmycia zostanie utracony ponieważ jest to stara wersja pliku. Kontynuować otwieranie go?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="757"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="385"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="128"/>
        <location filename="../src/service/filehander.cpp" line="202"/>
        <source>The file is in an older version, and the properties of elements will be changed. Proceed to open it?</source>
        <translation>Plik jest w starszej wersji i właściwości elementów zostaną zmienione. Kontynuować otwieranie go?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="462"/>
        <source>Unable to save. There is not enough disk space.</source>
        <translation>Błąd zapisu. Brak miejsca na dysku.</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="287"/>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="300"/>
        <source>The dimensions of %1 exceed the canvas. How to display it?</source>
        <translation>Wymiary %1 wykroczyły poza płótno. Jak to wyświetlić? </translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Keep original size</source>
        <translation>Zachowaj oryginalny rozmiar</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Auto fit</source>
        <translation>Auto dopasowywanie</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="296"/>
        <source>Apply to all</source>
        <translation>Zastosuj do wszystkich</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="755"/>
        <source>%1 has been modified in other programs. Do you want to reload it?</source>
        <translation>%1 został zmodyfikowany innymi programami. Chcesz go otworzyć?</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="756"/>
        <source>Reload</source>
        <translation>Załadować</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="1289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1691"/>
        <source>Import failed: no more than 10,000 pixels please</source>
        <translation>Import zakończony niepowodzeniem: przekroczono 10,000 pikseli</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/dialog.h" line="45"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="37"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1224"/>
        <source>Opening...</source>
        <translation>Otwieranie...</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="158"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Zaznacz wszystko</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Wytnij</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="vanished">Cofnij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Wklej</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">Grupa</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="vanished">Odznacz grupowanie</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="72"/>
        <location filename="../src/application.cpp" line="80"/>
        <source>DDF Drawings</source>
        <translation>Rysunki DDF</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="34"/>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="35"/>
        <source>Drawing</source>
        <translation>Rysowanie</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="36"/>
        <source>Shapes/Images</source>
        <translation>Kształty/Obrazy</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="37"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="38"/>
        <source>Align</source>
        <translation>Wyrównaj</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="42"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="43"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="44"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="45"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="46"/>
        <source>Save as</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="47"/>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="50"/>
        <source>Select</source>
        <translation>Zaznacz</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="51"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="52"/>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="53"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="54"/>
        <source>Triangle</source>
        <translation>Trójkąt</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="55"/>
        <source>Star</source>
        <translation>Gwiazda</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="56"/>
        <source>Polygon</source>
        <translation>Wielokąt</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="57"/>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="59"/>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="58"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="60"/>
        <source>Eraser</source>
        <translation>Gumka</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="61"/>
        <source>Blur</source>
        <translation>Rozmazanie</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="62"/>
        <source>Crop</source>
        <translation>Przytnij</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="63"/>
        <source>Expand canvas</source>
        <translation>Rozszerz obszar roboczy</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="64"/>
        <source>Shrink canvas</source>
        <translation>Zmniejsz obszar roboczy</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="69"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="70"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="71"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="72"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="73"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="74"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="75"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="76"/>
        <source>Ungroup</source>
        <translation>Odznacz grupowanie</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="77"/>
        <source>Raise Layer</source>
        <translation>Warstwa wyżej</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="78"/>
        <source>Lower Layer</source>
        <translation>Warstwa niżej</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="79"/>
        <source>Layer to Top</source>
        <translation>Warstwa na wierzch</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="80"/>
        <source>Layer to Bottom</source>
        <translation>Warstwa na spód</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="87"/>
        <source>Align left</source>
        <translation>Wyrównaj do lewej</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="88"/>
        <source>Align right</source>
        <translation>Wyrównaj do prawej</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="89"/>
        <source>Horizontal centers</source>
        <translation>Horyzontalne środki</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="90"/>
        <source>Align top</source>
        <translation>Wyrównaj do góry</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="91"/>
        <source>Align bottom</source>
        <translation>Wyrównaj do dołu</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="92"/>
        <source>Vertical centers</source>
        <translation>Pionowe środki</translation>
    </message>
</context>
<context>
    <name>TabBarWgt</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="120"/>
        <source>Close tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="125"/>
        <source>Close other tabs</source>
        <translation>Zamknij inne karty</translation>
    </message>
</context>
<context>
    <name>TopTilte</name>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="173"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="178"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="199"/>
        <location filename="../src/frame/toptoolbar.cpp" line="225"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="189"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="194"/>
        <source>Save as</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="209"/>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="242"/>
        <source>Draw</source>
        <translation>Draw</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="245"/>
        <source>Draw is a lightweight drawing tool for users to freely draw and simply edit images. </source>
        <translation>Draw to lekkie narzędzie do rysowania, które pozwala użytkownikom swobodnie rysować i po prostu edytować obrazy.</translation>
    </message>
</context>
</TS>